/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*- */

#include "framecpp/Common/MemoryBuffer.hh"

namespace FrameCPP
{
  namespace Common
  {
    //-------------------------------------------------------------------
    /// The default constructor will initialize all the parts used
    /// in the general case.
    //-------------------------------------------------------------------
    MemoryBuffer::
    MemoryBuffer( std::ios::openmode Mode,
                  bool ParentAutoDelete )
      : buffer_type( Mode )
    {
      AutoDelete( ParentAutoDelete );
    }

    //-------------------------------------------------------------------
    /// Be careful to release all the resources that were created
    /// for this object.
    //-------------------------------------------------------------------
    MemoryBuffer::
    ~MemoryBuffer( )
    {
    }

    //-------------------------------------------------------------------
    /// Filtering currently is not optimized at the this layer so
    /// this method will always return false.
    //-------------------------------------------------------------------
    bool MemoryBuffer::
    FilterInternally( ) const
    {
      return false;
    }

    void MemoryBuffer::
    buffer( )
    {
      //-----------------------------------------------------------------
      // There is no special initialization that needs to happen
      //-----------------------------------------------------------------
    }

    //-------------------------------------------------------------------
    /// \brief Perform filtering operations on the stream
    //-------------------------------------------------------------------
    void MemoryBuffer::
    filter( const char_type* Begin,
            const char_type* End )
    {
      std::cerr << "DEBUG:MemoryBuffer::filter:"
                << " Begin: " << (void*)Begin
                << " End: " << (void*)End
                << std::endl
        ;
    }

  } // namespace Common

} // namespace FrameCPP
